package Bundle::Modules::Acme::Everything::Unique;

use 5.005;

our $VERSION = 2006.0517; ## (YYYY.MMDD)

1;

__END__

=head1 NAME

Bundle::Modules::Acme::Everything::Unique - All current I<stable> and I<unique> modules in Bundle::Modules::Acme::Everything

=head1 SYNOPSIS

perl -MCPAN -e B<'install Bundle::Modules::Acme::Everything::Unique'>

cpan B<-i Bundle::Modules::Acme::Everything::Unique>

=head1 CONTENTS

Finance::Bank::Commonwealth
Search::Kinosearch
HtDig::Htsearch
SVN::Look
Watchdog::Service
MSSQL::DBlib
WWW::Scrobbler::Stats
WING
Neural
Class::PublicInternal
Plugin::Language::DML
WebService::BabelFish
Proc::times
MIME::IO
Scalar::Footnote
Data::Dumper::HTML
MSDOS::SysCalls
Oracle::OCI
Getopt::EvaP
GD::Gauge
PGP
NexTrieve::Search
AI::Categorize
Getopt::Gnu
Ioctl
UUID
Net::IPP
X11::XRT
Net::DHCP
VMS::User
Perl6::Doc
Devel::Truth_Table
Gemstone
CGI::FormManager
Lingua::FeatureSet
Device::SerialPort::Xmodem
CGI::CList
WWW::ShopBot
Tie::Plural::Scalar
CGI::SimpleCache
MARC
Filesys::mntent
Lemonolap
NexTrieve::Mbox
Bio::Genex
Slash
POE::Session::GladeXML
Math::FresnalZone
Text::Wrap::Hyphenate
HTML::Formulate
ERG
Math::Geometry
Win32::ODBC
ePortal
Archive::Parity
NexTrieve::Hitlist
Fame
NexTrieve
NetCDF
Authorizenet
Term::Size::Heuristic
Parse::Lexer
Pod::MIF
PerlMenu
Exporter::Import
News::Search
HTML::Demoroniser
NexTrieve::Collection
NexTrieve::Querylog
Tk::FlatCheckbox
Lexical::Typeglob
Font::TTF
GSM::SMS
Proxy::Tk
Python
Boulder
File::Size
File::MultiTail
Business::OnlinePayment::Moneris
Getopt::Help
NexTrieve::Docseq
Text::Wigwam
Text::Substitute
Log::Check
Palm::Magellan::NavCompanion
EventServer::Gettimeofday
IO::Redirect
RFID::Matrics
MMDS
MIME::Latin1
MSSQL::Sqllib
Lingua::PT
Win32::FUtils
IPC::UPDmsg
Convert::Lucene
Tree::List2Tree
Image::Magick::BarChart
NexTrieve::Message
WIN32::MSI::SummaryInfo
VMS::Queue
Algorithm::Munkre
WWW::Lyrics
PostScript::Barcode
NexTrieve::Replay
Text::Banner
LockFile::Scheme
Tk::Statusbar
Tie::Array::Huge
DBD::Altera
XML
Openview::Message
Python::Err
AI::NeuralNet
Date:Jalali
Quiz::Question
NexTrieve::PDF
GSS
VMS::Misc
Win32::Pipe
Solaris::PerlGcc
HTML::BarChart
NexTrieve::Resource
SGML::SPGrove
EventServer::Signal
RFID::EPC
AFS::Command
BnP
Chart::Gdchart
App::Config
ex::caution
PixDraw
Data::FormValidator::Upload
ControlX10::CM10
XMLI
Mail::Maildir
DBD::Recall
Crypt::Schnorr::AuthSign
Win32::MSI
IO::Filter
GISI::MIFMID
VMS::Monitor
Protect
HTML::Debug
PostScript::Basic
DBD::FreeTDS
GISI
String::Ruby
Tern::Size::Heuristic
Regexp::Func
Business::OnlinePayment::E2Payments
NexTrieve::Query
PDL::LAPACK
PerlPoint::Package
Tree::Menu
Devel::PerlySense
Watchdog::MysqlService
Tk::DBIx
Text::Bib
VMS::Priv
Language::VBParser
Win32::Message
Win32::IIS:SMTP
File::sudoers
Tk::Multi
Thread::Group
Tie::RndHash
Frontier::RPC
Persistence::Object
PDF::Report::Table
Tk::Olwm
Time::JulianDateTime
WWW::Mail::Hotmail
Oak
Convert::Base
Fortran::NameList
ElectricArc
NexTrieve::RFC822
Cz::Speak
Orac
OpenCA
PDF::PlainLayout
Mail::MH
Class::TOM
CGI::Session::Encrypted
BoxBackup
Remedy::AR
Carp::CheckArgs
Archive::Cabinet
Template::TagParser
Hardware::Simulator
AFS
Time:Compare
File::Data
FileSys::Tree
NexTrieve::MIME
Proc::ExitStatus
DBIx::TableAdapter
SOOP
RPM::Headers
Attribute::Abstract
SVG::Template
Win32::Perfmon
MOP
CGI::Query
Proc::PID::File::Fcntl
RFID::Alien
SQL::QueryBroker
Devel::Trampoline
DBD::SQLrelay
WWW::Webjay
SQL::Builder
Chart::Pie3d
HTML::Info
Net::ICAP
Widget::FixedWidthFont::Input
GD::Barcode::Code93
Exporter::PkgAlias
Tk::SignOnDialog
CGI::Request
CGI::DBTables
GISI::SHAPE
Smirch
Finance::Bank::DE::SpardaBank
Games::Go::GoPair
Lemonldap::Portal
CfgTie
Finance::Shares::MySQL
NexTrieve::Targz
Bio::SAGE
Text::Parser
Synergy
FameHLI
Bio::Affymetrix
Tk::ReportBox
Win32::GUID
CORBA::Python
Data::Stash
HPUX::Ioscan
Astro::SkyCoords
Math::BigIntFast
Bleach
Class::Flyweight
NexTrieve::UTF8
Interface::Param
Chatbot::RiveScript
W3C::LinkChecker
HTML::Widgets::DateEntry
Mobile::WURFL
DBIx::SchemaView
WWW::TVguide::NL
Sys::Sysconf
Filesys::statfs
File::ManualFlock
NexTrieve::Overview
SMIMEUtil
Class::Holon
WWW::Lunarstorm
CMS::Mediawiki
VMS::System
Physics::Solar::VSO
VMS::smg
Math::Interpolate
Crypt::OpenSSL::BN
Class::Eroot
Getopt::Long::File
Parse::YALALR
NexTrieve::Hitlist::Hit
DBD::RDB
NexTrieve::Collection::Index
Splash::DB
NexTrieve::Daemon
DBA::Backup
Glade
PDL::IO::HDF5
CGI::MiniSvr
Ratpoison
Linksys::Config
RT
SICStus
xDash
Mail::vpopmaild
VMS::Process
WWW::Search::Excite
File::Atomic
Business::Payroll::AU::PAYG
Lingua::EN::Cardinal
VMS::ICC
SQL::Routine
Win32::FileType
Image::ASCII
Net::Mac::Vendor
JUNOS
CGI::Base
DBD::Google
RFID::Base
Config::Ini
Unix::UserAdmin
IPC::Shm::Simple
PDF::Template
Tk::PhotoRotate
DBIx::XMLMEssage
Fax::DataFax
Module::MakeDist
Tk::Autoscroll
PDL::Slatec
ToolTalk
Text::Stem
Find::File::Object
VMS::Fileutils::Root
Clips
Tie::Mem
Archive::Tar::Stream
PDA::Pilot
Test::Litmus
Math::Matrix::SVD
Win32::AdminMisc
CGI::WebApp
HTML::Stripper
HtDig
SIL::Shoe
Mac::Spotlight
DBA::Backup::mysql
Watchdog::HTTPService
WWW::Search::Magellan
Tk::ImageButton
Crypt::ElGamal
Event::tcp
Lingua::EN::Ordinal
Filesys::dfent
Crypt::Camellia
Logfile
Business::OnlinePayment::Cybersource
Tie::Assert
Mail::DSN
CORBA::XPIDL
Religion::Package
DCE::RPC
Finance::Shares::Chart
Geo::Projection
CGI::FormFactory
Array::Reform
POE::Component::MPG123
Tie::WarnGlobal
TeX::Convert::Image
NexTrieve::Index
VMS::Persona
Datascope
NexTrieve::Document
Mail::Vacation::LDAP
Verilog::GetInfo
NexTrieve::DBI
EventServer::Functions
PDL::NetCDF
RTF::Generator
XML::Validator::RelaxNG
NexTrieve::HTML
Gtk::Dialog
Devel::DebugAPI
Net::USPS
Win32::GD
VMS::Fileutils::SafeName
Mail::Vacation
BizTalk
Tie::PerfectHash
Sort::PolySort
Sparky
PHP::MySQL_Session
X11::Toolkit
ReleaseAction
Math::SimpleInterest
Math::Nocarry
CGI::BasePlus
Mac::Serial
Zeta
Object::Info
X11::Xforms
Exporter::Options
Concurrent
VMS::Device
Mono

=head1 CHANGES

=over

=item 2006.0510 (YYYY.MMDD)

Initial version of: Bundle::Modules::Acme::Everything::Unique-2006.0510

This B<L<Bundle::Modules>> component package is in pre-alpha state with hash ordering.

The ordering of listed modules will eventually be prioritized for efficiency and completeness.

Modules commented out of this module list are either I<unstable> or I<stable> in the B<L<Bundle::Modules>> context.

Optimistically, if there are a lot of the modules commented out, then they are I<stable>, and we're listing I<unstable> context.

Optimistically, if there are a few of the modules commented out, then they are I<unstable>, and we're listing I<stable> context.

If you use the command C<B<man Bundle::Modules::Acme::Everything::Unique>>, type C<B</#>> to see the commented out modules as they're higlighted for you by B<man>.

=back

=head1 DESCRIPTION

This Bundle package will install all of the modules listed, if they're not commented out of the B<L<Bundle::Modules>> context.

=head1 SEE ALSO

I<L<Bundle::Modules>>, I<L<Bundle::Modules::Unstable>>, I<L<Bundle::Modules::CPAN>>, I<L<Bundle::Modules::CPAN::Unstable>>, I<L<Bundle::Modules::Apache>>, I<L<Bundle::Modules::Apache::Unstable>>, I<L<Bundle::Modules::Acme::Everything>>, I<L<Bundle::Modules::Acme::Everything::Unstable>>, I<L<Bundle::Modules::Acme::Everything::Unique::Unstable>>

=head1 AUTHORS

Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>

=head1 LICENSE for http://www.cpan.org/authors/id/E/ER/ERMEYERS/Bundle-Modules-2006.0517

perl

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=head1 COPYRIGHT

Copyright (c) 2006 by Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>


